#[non_exhaustive]pub struct RemoteVariationDeletePreflight {
pub remote: String,
pub variation: VariationId,
pub expected_remote_oid: String,
pub support_ref: String,
pub token: RemoteVariationDeleteToken,
pub can_delete: bool,
}Expand description
Preflight for removing a visible variation from a shared remote.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.remote: Stringvariation: VariationIdexpected_remote_oid: Stringsupport_ref: Stringtoken: RemoteVariationDeleteTokencan_delete: boolTrait Implementations
Sourceimpl Clone for RemoteVariationDeletePreflight
impl Clone for RemoteVariationDeletePreflight
Sourcefn clone(&self) -> RemoteVariationDeletePreflight
fn clone(&self) -> RemoteVariationDeletePreflight
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RemoteVariationDeletePreflight
impl<'de> Deserialize<'de> for RemoteVariationDeletePreflight
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteVariationDeletePreflight
Sourceimpl PartialEq for RemoteVariationDeletePreflight
impl PartialEq for RemoteVariationDeletePreflight
Sourcefn eq(&self, other: &RemoteVariationDeletePreflight) -> bool
fn eq(&self, other: &RemoteVariationDeletePreflight) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RemoteVariationDeletePreflight